@@ -49,6 +49,7 @@
 
 package com.openexchange.smtp;
 
+import static com.openexchange.mail.MailExceptionCode.getSize;
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import static com.openexchange.mail.mime.utils.MimeMessageUtility.parseAddressList;
 import static com.openexchange.mail.text.TextProcessing.performLineFolding;
@@ -73,6 +74,7 @@ import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.NoSuchProviderException;
+import javax.mail.Provider;
 import javax.mail.Transport;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
@@ -83,6 +85,9 @@ import javax.mail.internet.idn.IDNA;
 import javax.security.auth.Subject;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Filter;
+import com.openexchange.config.cascade.ConfigProperty;
+import com.openexchange.config.cascade.ConfigView;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
@@ -93,6 +98,7 @@ import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Java7ConcurrentLinkedQueue;
 import com.openexchange.java.StringAllocator;
+import com.openexchange.java.util.MsisdnCheck;
 import com.openexchange.log.LogProperties;
 import com.openexchange.log.Props;
 import com.openexchange.mail.MailExceptionCode;
@@ -126,8 +132,9 @@ import com.openexchange.smtp.config.MailAccountSMTPProperties;
 import com.openexchange.smtp.config.SMTPConfig;
 import com.openexchange.smtp.config.SMTPSessionProperties;
 import com.openexchange.smtp.filler.SMTPMessageFiller;
-import com.openexchange.smtp.services.SMTPServiceRegistry;
+import com.openexchange.smtp.services.Services;
 import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
+import com.sun.mail.smtp.JavaSMTPTransport;
 import com.sun.mail.smtp.SMTPMessage;
 
 /**
@@ -303,11 +310,34 @@ public final class SMTPTransport extends MailTransport {
         throw MailExceptionCode.UNEXPECTED_ERROR.create(cause, cause.getMessage());
     }
 
+    private long getMaxMailSize() throws OXException {
+        ConfigViewFactory factory = Services.getService(ConfigViewFactory.class);
+
+        if (factory != null) {
+            ConfigView view = factory.getView(session.getUserId(), session.getContextId());
+            ConfigProperty<Long> property = view.property("com.openexchange.mail.maxMailSize", Long.class);
+
+            if (property.isDefined()) {
+                Long l = property.get();
+                long maxMailSize = null == l ? -1 : l.longValue();
+                if (maxMailSize > 0) {
+                    return maxMailSize;
+                }
+            }
+        }
+
+        return -1;
+    }
+
     private javax.mail.Session getSMTPSession() throws OXException {
         if (null == smtpSession) {
             synchronized (this) {
                 if (null == smtpSession) {
                     final Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
+                    smtpProps.put("mail.smtp.class", JavaSMTPTransport.class.getName());
+                    smtpProps.put("com.openexchange.mail.maxMailSize", Long.toString(getMaxMailSize()));
+
+
                     final SMTPConfig smtpConfig = getTransportConfig0();
                     /*
                      * Set properties
@@ -373,7 +403,7 @@ public final class SMTPTransport extends MailTransport {
                          */
                         String hostName = smtpLocalhost;
                         if (null == hostName) {
-                            final HostnameService hostnameService = SMTPServiceRegistry.getServiceRegistry().getService(HostnameService.class);
+                            final HostnameService hostnameService = Services.getService(HostnameService.class);
                             if (null == hostnameService) {
                                 hostName = getHostName();
                             } else {
@@ -416,6 +446,12 @@ public final class SMTPTransport extends MailTransport {
                     // smtpProps.put(MIMESessionPropertyNames.PROP_SMTPHOST, smtpConfig.getServer());
                     // smtpProps.put(MIMESessionPropertyNames.PROP_SMTPPORT, sPort);
                     smtpSession = javax.mail.Session.getInstance(smtpProps, null);
+                    smtpSession.addProvider(new Provider(
+                        Provider.Type.TRANSPORT,
+                        "smtp",
+                        JavaSMTPTransport.class.getName(),
+                        "Open-Xchange, Inc.",
+                        "7.2.2"));
                 }
             }
         }
@@ -798,7 +834,8 @@ public final class SMTPTransport extends MailTransport {
         }
     }
 
-    private void transport(final MimeMessage smtpMessage, final Address[] recipients, final Transport transport, final SMTPConfig smtpConfig) throws OXException {
+    private void transport(final MimeMessage smtpMessage, final Address[] recipients, Transport transport, final SMTPConfig smtpConfig) throws OXException {
+        prepareAddresses(recipients);
         try {
             transport.sendMessage(smtpMessage, recipients);
         } catch (final MessagingException e) {
@@ -812,6 +849,10 @@ public final class SMTPTransport extends MailTransport {
                     transportAlt(smtpMessage, recipients, transport, smtpConfig);
                     return;
                 }
+            } else if (e.getNextException() instanceof IOException) {
+                if (e.getNextException().getMessage().equals("Maximum message size is exceeded.")) {
+                    throw MailExceptionCode.MAX_MESSAGE_SIZE_EXCEEDED.create(getSize(getMaxMailSize(), 2, false, true));
+                }
             }
             throw MimeMailException.handleMessagingException(e, smtpConfig, session);
         }
@@ -854,6 +895,22 @@ public final class SMTPTransport extends MailTransport {
         return tmpPass;
     }
 
+    private void prepareAddresses(final Address[] addresses) {
+        final int length = addresses.length;
+        final StringBuilder tmp = new StringBuilder(32);
+        for (int i = 0; i < length; i++) {
+            final InternetAddress address = (InternetAddress) addresses[i];
+            final String sAddress = address.getAddress();
+            if (MsisdnCheck.checkMsisdn(sAddress)) {
+                final int pos = sAddress.indexOf('/');
+                if (pos < 0) {
+                    tmp.setLength(0);
+                    address.setAddress(tmp.append(sAddress).append("/TYPE=PLMN").toString());
+                }
+            }
+        }
+    }
+
     @Override
     protected void shutdown() {
         SMTPSessionProperties.resetDefaultSessionProperties();
@@ -869,7 +926,7 @@ public final class SMTPTransport extends MailTransport {
         if ((recipients == null) || (recipients.length == 0)) {
             throw SMTPExceptionCode.MISSING_RECIPIENTS.create();
         }
-        final ConfigurationService service = SMTPServiceRegistry.getServiceRegistry().getService(ConfigurationService.class);
+        final ConfigurationService service = Services.getService(ConfigurationService.class);
         if (null != service) {
             final Filter filter = service.getFilterFromProperty("com.openexchange.mail.transport.redirectWhitelist");
             if (null != filter) {
@@ -933,8 +990,7 @@ public final class SMTPTransport extends MailTransport {
     @Override
     protected ITransportProperties createNewMailProperties() throws OXException {
         try {
-            final MailAccountStorageService storageService =
-                SMTPServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class, true);
+            final MailAccountStorageService storageService = Services.getService(MailAccountStorageService.class);
             return new MailAccountSMTPProperties(storageService.getMailAccount(accountId, session.getUserId(), session.getContextId()));
         } catch (final OXException e) {
             throw e;
@@ -942,7 +998,7 @@ public final class SMTPTransport extends MailTransport {
     }
 
     private void saveChangesSafe(final MimeMessage mimeMessage) throws OXException {
-        final HostnameService hostnameService = SMTPServiceRegistry.getServiceRegistry().getService(HostnameService.class);
+        final HostnameService hostnameService = Services.getService(HostnameService.class);
         String hostName;
         if (null == hostnameService) {
             hostName = getHostName();
@@ -1021,7 +1077,7 @@ public final class SMTPTransport extends MailTransport {
         final int len = string.length();
         boolean isWhitespace = true;
         for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = Character.isWhitespace(string.charAt(i));
+            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
         }
         return isWhitespace;
     }
