@@ -51,8 +51,8 @@ package com.openexchange.smtp.filler;
 
 import java.io.IOException;
 import javax.mail.MessagingException;
-import javax.mail.internet.IDNA;
 import javax.mail.internet.MimeMessage;
+import javax.mail.internet.idn.IDNA;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.UserStorage;
